==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="gl" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Crear folla de cálculo</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Crear una folla de cálculo nova</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Aliñación inferior</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Aliñado inferior do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Aliñación centrada</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Aliñado ó centro do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Aliñación esquerda</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Aliñado á esquerda do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Aliñación dereita</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Aliñado á dereita do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Aliñación superior</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Aliñado á cima do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Aliñación verticalmente centrada</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>Aliñado verticalmente ó centro do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exportar folla de cálculo</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Exporta folla de cálculo como ficheiro CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importar folla de cálculo</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importa folla de cálculo como ficheiro CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Combinar celas</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Combina as celas escolmadas nunha, na folla de cálculo</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Definir alcume</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Define un alcume para as celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Dividir cela</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Divide celas combinadas anteriormente na folla de cálculo</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Texto en grosa</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Establece o texto das celas escolmadas en grosa</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Texto en cursiva</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Establece o texto das celas escolmadas en cursiva</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Texto subliñado</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>Suliñar texto en celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Personalizar cor</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Propiedades da cela</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp; Cor</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Texto</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fondo</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Aliñamento</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Esquerda</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Centro</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Dereita</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Enriba</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Embaixo</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Estilo</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Grosa</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Cursiva</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Subliñado</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Amosar unidade</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Sufixo da unidade</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lcume</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alcume para esta cela</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Todos (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importar ficheiro</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exportar ficheiro</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Contido da cela</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Amosar a folla de cálculo</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Definir cor de primeiro plano da(s) célula(s)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Definir cor de primeiro plano da(s) célula(s) da folla de cálculo</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Definir cor do plano de fondo da(s) célula(s)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Definir a cor do plano de fondo da(s) célula(s) da folla de cálculo</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Negro</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Branco</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Vermello</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Vermello escuro</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Verde</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Verde escuro</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Azul</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Azul escuro</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cíano</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Ciano escuro</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Maxenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Maxenta escuro</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Marelo</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Marelo escuro</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Gris</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Gris escuro</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Gris claro</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Personalizar</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Formulario</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Contidos</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Sen nome</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Inserir ringleiras</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Desbotar ringleiras</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Inserir columnas</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Desbotar columnas</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Propiedades...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.2+dfsg1.orig.tar.xz: FreeCAD-0.19.2/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_gl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Crear folla de cálculo</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Crear una folla de cálculo nova</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Aliñación inferior</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Aliñado inferior do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Aliñación centrada</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Aliñado ó centro do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Aliñación esquerda</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Aliñado á esquerda do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Aliñación dereita</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Aliñado á dereita do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Aliñación superior</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Aliñado á cima do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Aliñación verticalmente centrada</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation>Aliñado verticalmente ó centro do contido das celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exportar folla de cálculo</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Exporta folla de cálculo como ficheiro CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importar folla de cálculo</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importa folla de cálculo como ficheiro CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Combinar celas</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation>Fundir celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Definir alcume</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Define un alcume para as celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Dividir cela</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation>Dividir celas previamente mesturadas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Texto en grosa</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation>Conxunto de texto en celas escolmadas en negro</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Texto en cursiva</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation>Conxunto de texto en celas escolmadas en itálica</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Texto subliñado</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation>Suliñar texto en celas escolmadas</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation>Personalizar cor</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Combinar celas</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Dividir cela</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation type="unfinished">Left-align cell</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation type="unfinished">Center cell</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation type="unfinished">Right-align cell</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation type="unfinished">Top-align cell</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation type="unfinished">Bottom-align cell</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation type="unfinished">Vertically center cells</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation type="unfinished">Set bold text</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation type="unfinished">Set italic text</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation type="unfinished">Set underline text</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation type="unfinished">Create Spreadsheet</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation type="unfinished">Set cell properties</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation type="unfinished">Edit cell</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Inserir ringleiras</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Desbotar ringleiras</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Inserir columnas</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation type="unfinished">Clear cell(s)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation type="unfinished">Set foreground color</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation type="unfinished">Set background color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Propiedades da cela</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp; Cor</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Texto</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Fondo</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Aliñamento</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation>Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Esquerda</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Centro</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Dereita</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation>Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Enriba</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Embaixo</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>&amp;Estilo</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Grosa</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Cursiva</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Subliñado</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Amosar unidade</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Sufixo da unidade</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation>A&amp;lcume</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alcume para esta cela</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Todos (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importar ficheiro</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exportar ficheiro</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Amosar a folla de cálculo</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation>Definir cor de primeiro plano da(s) célula(s)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation>Definir cor de primeiro plano da(s) célula(s) da folla de cálculo</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation>Definir cor do plano de fondo da(s) célula(s)</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation>Definir a cor do plano de fondo da(s) célula(s) da folla de cálculo</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation type="unfinished">Spreadsheet does not support range selection when pasting.
Please select one cell only.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation type="unfinished">Copy &amp; Paste failed</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation type="unfinished">Alias contains invalid characters!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Negro</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Branco</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Vermello</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Vermello escuro</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Verde</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Verde escuro</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Azul</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Azul escuro</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation>Cíano</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Ciano escuro</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation>Maxenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Maxenta escuro</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Marelo</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Marelo escuro</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Gris</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Gris escuro</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Gris claro</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation>Personalizar cor</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Formulario</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation type="unfinished">&amp;Content:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation type="unfinished">&amp;Alias:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Sen nome</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Inserir ringleiras</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Desbotar ringleiras</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Inserir columnas</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Desbotar columnas</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Propiedades...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Folla de cálculo</translation>
    </message>
  </context>
</TS>
